% Example.m
%
% An example problem:
%
% Here we have 3 modalities (numMod = 3) with slopes (a's) = [.6 .7 .8],
% intercepts (b's) = [-.1 0 .1], and noise (sigma's) = [.05 .03 .08].
%
% Theta consists of 100 true ejection fractions (EFs) - they are beta 
% distributed with nu = 1.5 and omega = 2.  GenData modifies the true EFs
% with the linear model parameters (a's,b's,sigma's) to give us our data:
% ThetaHat.  
%
% Opt_normal maximizes the likelihood of the data given the model
% parameters and the parameters of the assumed distribution (in this case a
% truncated normal).  
%
% MakePlots generates plots using the data (ThetaHats) versus the
% true EFs (Theta's) and the estimated linear model parameters.  Note that
% the true EFs were not used to estimate the linear model parameters.  We
% are only able to generate these plots because we now the truth in
% simulation. 
%
% Here the data (beta distributed) did not match the model (truncated
% normal).  One is free to change this around by replacing betarnd with
% truncnorm and/or Opt_tnormal with Opt_beta.  
%
% Papers on the subject can be found at:
%
% http://www.ieee-tmi.org/
% Title: Objective Comparison of Quantitative Imaging Modalities Without the
% Use of a Gold Standard
% May 2002 issue
%
% http://www.academicradiology.com/AR_2002/Mar02/Mar_2002.htm
% Title: Estimation in Medical Imaging without a Gold Standard
% March 2002 issue
% -----
% GENERATING TRUTH: Theta
% 
% Beta distributed: Use betarnd(nu,omega,P,1) (P is patient number)
%
% Truncated normal distributed: Use truncnorm.m
% 
% function vals = truncnorm(mu,sig,num)
% 
% Generating truncated normal distributed data
%
% Note that mu and sigma here are the mean and standard deviation of the
% normal we are truncating.  They are NOT the mean and standard deviation of
% the truncated normal.
%
% -----
% GENERATING DATA: ThetaHat
%
% Use GenData.m
%
%  Given the "Truth" (Theta), generate noisy measument data of the form
%  ThetaHat = a*Theta + b + noise(sig).  Where a, b, and sig are vectors
%  whose size determines the number of noisy measurements.
%
%  Example:  >> Theta = betarnd(1.5,2,100,1);  % Generate "Truth"
%            >> ThetaHat = GenData(Theta,[.5 .8],[0 0],[0.05 0.01]);
%
%  Note:  This generates Gaussian noise on the measurement data.
%
% -----
% OPTIMIZE COST FUNCTION: Estimates linear model parameters
%
% For beta assumed distribution (beta in cost function)
% 
% Use Opt_beta.m:
%
% function  [aEst,bEst,sigEst,betaP] = Opt_beta(ThetaHat,a,b,sig,dim)
%
% Run the "Estimation w/out a Gold Standard" routine using a varying Beta
% distrubtion as the assumed distribution.
%
% ThetaHat is generated using GenData.m
% Returns maximum-likelihood estimates of the linear model parameters
% {a,b,\sigma,\nu,\omega}
%
% For truncated normal distribution (trunc norm in cost function)
%
% Use Opt_tnormal.m:
%
% function  [aEst,bEst,sigEst,meanpEst,sigpEst] = Opt_tnormal(ThetaHat)
%
% Run the "Estimation w/out a Gold Standard" routine using a varying 
% truncated-normal
% distrubtion as the assumed distribution.
%
% ThetaHat is generated using GenData.m
% Returns maximum-likelihood estimates of the linear model parameters
% {a,b,\sigma,\mu_a,\sigma_a}
%
% -----
% PLOTTING DATA: Use MakePlots.m
% 
% MakePlots(Theta,ThetaHat,a,b,sig)
%
% Makes regression plots given true EFs (Theta), estimated EFs (ThetaHat),
% and estimated linear model parameters (a,b,sig) which are vectors of
% dimension 1 x numMod. 
%
% -----
% COST FUNCTIONS: You must have these in the same directories as the
% optimazation routines.
%
% Beta: betacostfun.m
%
%  Has a _varying_ beta assumed distribution
%
%  params = [a's b's sig's nu omega]
%
% Truncated normal: truncnormalcostfun.m
%
% Has a _varying_ normal assumed distribution.
%
% params = [a's b's sig's meanp sigp]
%
 